# pymdisp

pymdisp is a message dispatcher intended for use in Telegram bots and things alike. It allows to write readable code instead of mangled states

## Installation

`pip install pymdisp`

## Usage

You can find a live example in [live\_example/bot.py](live_example/bot.py)
